﻿/*==============================================================================
*
*       filename        dllentry.cpp
*       purpose         API for dynamic loading okapi64.dll or okapi32.dll (Ok series image cards)
*       language        Microsoft Visual C 5.0
*       author          S. Yang
*       date            mon-date-99
*-----------------------
*       modify by       dingwen
*       purpose         
*       language        c++
*       date            2022.2.11
*
*-----------------------
*
*		Copyright (C).  All Rights Reserved.
*
*
*==============================================================================
*       language include files
*/


#include<stdio.h>
#include<stdlib.h>
#include <memory.h>
#include <time.h>

#include <QApplication>

#if defined(Q_OS_WIN64)
    #include<windows.h>
    #include "Okapi64.h"
    #define DLLNAME "okapi64.dll"
#elif defined(Q_OS_WIN32)
    #include<windows.h>
    #include "Okapi32.h"
    #define DLLNAME "okapi32.dll"
#else
    #include "../share/winsim.h"
    #include "../share/okapi64.h"
    #define DLLNAME "libapi64.so"
#endif

/*-----------------------------------------------------------------------------
*       Functions Pointors
*/

//1. section

typedef HANDLE	(WINAPI *pOpenBoard)(MLONG *);
pOpenBoard lpfnOpenBoard;
typedef HANDLE	(WINAPI *pOpenBoardEx)(MLONG *, HANDLE, LPVOID);
pOpenBoardEx lpfnOpenBoardEx;
typedef BOOL	(WINAPI *pCloseBoard)(HANDLE);
pCloseBoard lpfnCloseBoard;
typedef INT32	(WINAPI *pGetLastError)(void);
pGetLastError lpfnGetLastError;
typedef MLONG	(WINAPI *pGetBufferSize)(HANDLE hBoard, void **lpLinear, MWORD *dwSize);
pGetBufferSize lpfnGetBufferSize;
typedef LPVOID 	(WINAPI *pGetBufferAddr)(HANDLE hBoard, MLONG iNoFrame);
pGetBufferAddr lpfnGetBufferAddr;
typedef LPVOID  (WINAPI *pGetTargetInfo)(HANDLE hBoard, TARGET tgt, MLONG lNoFrame, SHORT * wid, SHORT * ht, MLONG *stride);
pGetTargetInfo lpfnGetTargetInfo;
typedef INT32	(WINAPI *pGetTypeCode)(HANDLE hBoard,LPSTR lpBoardName);
pGetTypeCode lpfnGetTypeCode;
typedef INT32	(WINAPI *pGetNetDevNumber)(INT32 iTypeCode, LPSTR lpNameString);
pGetNetDevNumber lpfnGetNetDevNumber;
typedef MLONG	(WINAPI *pSetTargetRect)(HANDLE hBoard, TARGET target, LPRECT lpTgtRect);
pSetTargetRect lpfnSetTargetRect;
typedef INT32	(WINAPI *pSetToWndRect)(HANDLE hBoard, HWND hWnd);
pSetToWndRect lpfnSetToWndRect;
typedef MLONG	(WINAPI *pSetVideoParam)(HANDLE hBoard, INT32 wParam, MLONG lParam);
pSetVideoParam lpfnSetVideoParam;
typedef MLONG	(WINAPI *pSetCaptureParam)(HANDLE hBoard, INT32 wParam, MLONG lParam);
pSetCaptureParam lpfnSetCaptureParam;
typedef MLONG	(WINAPI *pSetDeviceParam)(HANDLE hBoard, INT32 wParam, MLONG lParam);
pSetDeviceParam lpfnSetDeviceParam;
typedef MLONG	(WINAPI *pSetUserData)(HANDLE hBoard, MLONG mUserData);
pSetUserData lpfnSetUserData;
typedef BOOL	(WINAPI *pSetSeqProcWnd)(HANDLE hBoard, HWND hwndMain);
pSetSeqProcWnd lpfnSetSeqProcWnd;
typedef BOOL	(WINAPI *pSetSeqCallback)(HANDLE hBoard,
								BOOL CALLBACK BeginProc(HANDLE hBoard), 
								BOOL CALLBACK SeqProc(HANDLE hBoard, MLONG No), 
								BOOL CALLBACK EndProc(HANDLE hBoard));
pSetSeqCallback lpfnSetSeqCallback;
typedef BOOL	(WINAPI *pSetEventCallback)(HANDLE hBoard, INT32 iEvent, BOOL CALLBACK EventProc(HANDLE hBoard, MWORD dwReserved) );
pSetEventCallback lpfnSetEventCallback;
typedef BOOL	(WINAPI *pSetCloseCallback)(HANDLE hBoard, BOOL CALLBACK CloseProc(HANDLE hBoard, MWORD dwRes));
pSetCloseCallback lpfnSetCloseCallback;
typedef MLONG	(WINAPI *pCaptureTo)(HANDLE hBoard, TARGET Dest, MLONG start, MLONG lParam);
pCaptureTo lpfnCaptureTo;
typedef BOOL	(WINAPI *pCaptureSingle)(HANDLE hBoard, TARGET Dest, MLONG lStart);
pCaptureSingle lpfnCaptureSingle;
typedef BOOL	(WINAPI *pCaptureActive)(HANDLE hBoard, TARGET Dest, MLONG lStart);
pCaptureActive lpfnCaptureActive;
typedef HANDLE	(WINAPI *pCaptureThread)(HANDLE hBoard, TARGET Dest, MLONG lStart, MLONG lNoFrame);
pCaptureThread lpfnCaptureThread;
typedef BOOL	(WINAPI *pCaptureSequence)(HANDLE hBoard, MLONG lStart, MLONG lNoFrame);
pCaptureSequence lpfnCaptureSequence;
typedef MLONG	(WINAPI *pCaptureToScreen)(HANDLE hBoard);
pCaptureToScreen lpfnCaptureToScreen;
typedef MLONG	(WINAPI *pPlaybackFrom)(HANDLE hBoard, TARGET src, MLONG start, MLONG lParam);
pPlaybackFrom lpfnPlaybackFrom;
typedef BOOL	(WINAPI *pPlaybackSequence)(HANDLE hBoard, MLONG lStart, MLONG lNoFrame);
pPlaybackSequence lpfnPlaybackSequence;
typedef MLONG	(WINAPI *pSetDriverParam)(INT32 lWhich, MLONG lParam);
pSetDriverParam lpfnSetDriverParam;
typedef MLONG	(WINAPI *pGetCaptureStatus)(HANDLE hBoard, BOOL bWait);
pGetCaptureStatus lpfnGetCaptureStatus;
typedef MLONG	(WINAPI *pGetLineReady)(HANDLE hBoard, MLONG *iCurrFrameNo, MWORD dwRes);
pGetLineReady lpfnGetLineReady;
typedef MLONG	(WINAPI *pStopCapture)(HANDLE hBoard);
pStopCapture lpfnStopCapture;
typedef MLONG	(WINAPI *pGetSeqCapture)(HANDLE hApi, MLONG start, MLONG count);
pGetSeqCapture lpfnGetSeqCapture;
typedef HANDLE	(WINAPI *pCaptureByBuffer)(HANDLE hBoard, TARGET tgt, MLONG start, MLONG num);
pCaptureByBuffer lpfnCaptureByBuffer;
typedef HANDLE	(WINAPI *pCaptureByBufferEx)(HANDLE hBoard, MLONG fileset, TARGET dest, MLONG start, MLONG num);
pCaptureByBufferEx lpfnCaptureByBufferEx;
typedef HANDLE	(WINAPI *pPlaybackByBuffer)(HANDLE hBoard, TARGET src, MLONG start, MLONG num);
pPlaybackByBuffer lpfnPlaybackByBuffer;
typedef INT32	(WINAPI *pReadPixel)(HANDLE hBoard, TARGET src, MLONG start, SHORT x, SHORT y);
pReadPixel lpfnReadPixel;
typedef INT32	(WINAPI *pWritePixel)(HANDLE hBoard, TARGET tgt, MLONG start, SHORT x, SHORT y,  INT32 lValue);
pWritePixel lpfnWritePixel;
typedef MLONG	(WINAPI *pSetConvertParam)(HANDLE hBoard, INT32 wParam, MLONG lParam);
pSetConvertParam lpfnSetConvertParam;
typedef INT32	(WINAPI *pReadRect)(HANDLE hBoard, TARGET src, MLONG start, LPBYTE lpBuf);
pReadRect lpfnReadRect;
typedef INT32	(WINAPI *pWriteRect)(HANDLE hBoard, TARGET dst, MLONG start, LPBYTE lpBuf);
pWriteRect lpfnWriteRect;
typedef INT32	(WINAPI *pTransferRect)(HANDLE hBoard, TARGET dest, MLONG iFirst, TARGET src, MLONG iStart, MLONG lNum);
pTransferRect lpfnTransferRect;
typedef INT32	(WINAPI *pConvertRect)(HANDLE hBoard, TARGET dst, MLONG first, TARGET src, MLONG start, MLONG no);
pConvertRect lpfnConvertRect;
typedef INT32	(WINAPI *pConvertRectEx)(HANDLE hDstBoard, TARGET dst, MLONG first, HANDLE hSrcBoard,TARGET src, MLONG start, MLONG no);
pConvertRectEx lpfnConvertRectEx;
typedef INT32	(WINAPI *pReadRectEx)(HANDLE hBoard, TARGET src, MLONG start, LPBYTE lpBuf, INT32 lParam);
pReadRectEx lpfnReadRectEx;
typedef INT32	(WINAPI *pWriteRectEx)(HANDLE hBoard, TARGET dst, MLONG start, LPBYTE lpBuf, INT32 lParam);
pWriteRectEx lpfnWriteRectEx;
#if defined(Q_OS_WIN32)
typedef BOOL	(WINAPI *pSetTextTo)(HANDLE hBoard, TARGET target, LPRECT lpRect, LOGFONT *lfLogFont, SETTEXTMODE *textMode, LPSTR lpString, INT32 lLength);
pSetTextTo lpfnSetTextTo;
#endif
typedef INT32	(WINAPI *pDrawLineTo)(HANDLE hBoard, TARGET target, MLONG lStart, POINT pt0, POINT pt1, INT32 iForeColor);
pDrawLineTo lpfnDrawLineTo;
typedef INT32	(WINAPI *pDrawEllipsTo)(HANDLE hBoard, TARGET target, MLONG lStart, LPRECT lpRect, INT32 iForeColor);
pDrawEllipsTo lpfnDrawEllipsTo;
typedef INT32	(WINAPI *pFillCircleTo)(HANDLE hBoard, TARGET target,MLONG lStart, LPRECT lpRect, INT32 iForeColor, INT32 lMode);
pFillCircleTo lpfnFillCircleTo;
typedef HDC		(WINAPI *pCreateDCBitmap)(HANDLE hBoard, TARGET target, HANDLE *hDCBitmap);
pCreateDCBitmap lpfnCreateDCBitmap;
typedef BOOL	(WINAPI *pMapDCBitmapTo)(HANDLE hDCBitmap, MLONG lStart);
pMapDCBitmapTo lpfnMapDCBitmapTo;
typedef BOOL	(WINAPI *pFreeDCBitmap)(HANDLE hDCBitmap);
pFreeDCBitmap lpfnFreeDCBitmap;
typedef BOOL	(WINAPI *pWaitVerticalSync)(HANDLE hBoard, BOOL bHeader);
pWaitVerticalSync lpfnWaitVerticalSync;
typedef INT32	(WINAPI *pGetSignalParam)(HANDLE hBoard, INT32 wParam);
pGetSignalParam lpfnGetSignalParam;
typedef INT32	(WINAPI *pWaitSignalEvent)(HANDLE hBoard, INT32 wParam, MLONG lMilliSecond);
pWaitSignalEvent lpfnWaitSignalEvent;
typedef MLONG	(WINAPI *pPutSignalParam)(HANDLE hBoard, INT32 wParam, MLONG lParam);
pPutSignalParam lpfnPutSignalParam;
typedef INT32	(WINAPI *pEnableMask)(HANDLE hBoard, BOOL bMask);
pEnableMask lpfnEnableMask;
typedef INT32	(WINAPI *pSetMaskRect)(HANDLE hBoard, LPRECT lpRect, LPBYTE lpMask);
pSetMaskRect lpfnSetMaskRect;
typedef INT32	(WINAPI *pFillOutLUT)(HANDLE hBoard,  LPVOID bLUT, INT32 offset, INT32 num);
pFillOutLUT lpfnFillOutLUT;
typedef INT32	(WINAPI *pFillInputLUT)(HANDLE hBoard,  LPVOID bLUT, INT32 offset, INT32 num);
pFillInputLUT lpfnFillInputLUT;
typedef INT32	(WINAPI *pGetImageDevice)(OKDEVTYPE **lpOkDevInfo, MLONG lpParam);
pGetImageDevice lpfnGetImageDevice;
typedef SHORT	(WINAPI *pGetSlotBoard)(BOARDTYPE **lpOkInfo);
pGetSlotBoard lpfnGetSlotBoard;
typedef SHORT	(WINAPI *pGetBoardIndex)(CHAR *szBoardName, SHORT iNo);
pGetBoardIndex lpfnGetBoardIndex;
typedef INT32	(WINAPI *pGetBoardName)(SHORT lIndex, LPSTR szBoardName);
pGetBoardName lpfnGetBoardName;
typedef MLONG	(WINAPI *pGetAvailBuffer)(void **lpLinear, MWORD *dwSize);
pGetAvailBuffer lpfnGetAvailBuffer;
typedef MLONG	(WINAPI *pLockBuffer)(HANDLE hBoard, MWORD dwSizeByte, void **lpBasLinear);
pLockBuffer lpfnLockBuffer;
typedef BOOL	(WINAPI *pUnlockAllBuffer)(void);
pUnlockAllBuffer lpfnUnlockAllBuffer;
typedef INT32	(WINAPI *pApplyMemBlock)(DWORD dwBlockSize, DWORD dwBlockNo);
pApplyMemBlock lpfnApplyMemBlock;
typedef BOOL	(WINAPI *pFreeMemBlock)(void);
pFreeMemBlock lpfnFreeMemBlock;
typedef INT32	(WINAPI *pGetMemBlock)(HANDLE hBoard, DWORD *dwEachSize,  DWORD *dwBlockNo);
pGetMemBlock lpfnGetMemBlock;
typedef INT32	(WINAPI *pLockMemBlock)(HANDLE hBoard, DWORD dwBlockNo);
pLockMemBlock lpfnLockMemBlock;
typedef BOOL	(WINAPI *pUnlockMemBlock)(void);
pUnlockMemBlock lpfnUnlockMemBlock;
typedef MLONG	(WINAPI *pMulCaptureTo)(HANDLE *lphBoard, TARGET Dest, MLONG start, MLONG lParam);
pMulCaptureTo lpfnMulCaptureTo;
typedef HANDLE	(WINAPI *pMulCaptureByBuffer)(HANDLE *lphBoard, TARGET tgt, MLONG start, MLONG num);
pMulCaptureByBuffer lpfnMulCaptureByBuffer;
typedef BOOL	(WINAPI *pSaveInitParam)(HANDLE hBoard, SHORT iChannNo);
pSaveInitParam lpfnSaveInitParam;
typedef BOOL	(WINAPI *pLoadInitParam)(HANDLE hBoard, SHORT iChannNo);
pLoadInitParam lpfnLoadInitParam;
typedef MLONG	(WINAPI *pSetAllocBuffer)(MLONG lSize);
pSetAllocBuffer lpfnSetAllocBuffer;
typedef BOOL	(WINAPI *pSetStaticVxD)(INT32 lMode);
pSetStaticVxD lpfnSetStaticVxD;
typedef BOOL	(WINAPI *pSetNTDriver)(BOOL bCmd);
pSetNTDriver lpfnSetNTDriver;
typedef INT32	(WINAPI *pSetLangResource)(INT32 bCmd);
pSetLangResource lpfnSetLangResource;
typedef BOOL	(WINAPI *pUnRegister)(DWORD dwCmd);
pUnRegister lpfnUnRegister;
typedef INT32	(WINAPI *pGetProgramInfo)(INT32 iItem, LPSTR lpString, INT32 iSize);
pGetProgramInfo lpfnGetProgramInfo;
typedef INT32	(WINAPI *pReadProtCode)(HANDLE hBoard, SHORT iIndex);
pReadProtCode lpfnReadProtCode;
typedef INT32	(WINAPI *pWriteProtCode)(HANDLE hBoard, SHORT iIndex, INT32 Code);
pWriteProtCode lpfnWriteProtCode;
typedef MLONG	(WINAPI *pSaveImageFile)(HANDLE hBoard, LPSTR szFileName, MLONG first, TARGET target, MLONG start, MLONG num);
pSaveImageFile lpfnSaveImageFile;
typedef MLONG	(WINAPI *pLoadImageFile)(HANDLE hBoard, LPSTR szFileName, MLONG first, TARGET target, MLONG start, MLONG num);
pLoadImageFile lpfnLoadImageFile;
typedef BOOL	(WINAPI *pGetCurrImageInfo)(HANDLE hBoard, MLONG lpImgFrmInfo, MLONG lSize);
pGetCurrImageInfo lpfnGetCurrImageInfo;
typedef BOOL	(WINAPI *pLoadConfigFile)(HANDLE hBoard, LPSTR szFileName);
pLoadConfigFile lpfnLoadConfigFile;
typedef BOOL	(WINAPI *pSaveConfigFile)(HANDLE hBoard, LPSTR szFileName);
pSaveConfigFile lpfnSaveConfigFile;
typedef BOOL	(WINAPI *pLoadFlatModelFile)(HANDLE hBoard, LPSTR szFileName);
pLoadFlatModelFile lpfnLoadFlatModelFile;
typedef BOOL	(WINAPI *pSaveFlatModelFile)(HANDLE hBoard, LPSTR szFileName);
pSaveFlatModelFile lpfnSaveFlatModelFile;
typedef BOOL	(WINAPI *pOpenSetParamDlg)( HANDLE hBoard, HWND hParentWnd);
pOpenSetParamDlg lpfnOpenSetParamDlg;
typedef BOOL	(WINAPI *pOpenSeqCaptureDlg)( HANDLE hBoard, HWND hParentWnd);
pOpenSeqCaptureDlg lpfnOpenSeqCaptureDlg;
typedef LPDIBINFO (WINAPI *pOpenReplayDlg)( HANDLE hBoard, HWND hWnd, TARGET src, MLONG total);
pOpenReplayDlg lpfnOpenReplayDlg;
typedef HWND     (WINAPI *pOpenReplayDlgEx)( HANDLE hBoard, HWND hWnd, TARGET src, MLONG total,LPBITMAPINFOHEADER lpbi, LPBYTE lpdib);
pOpenReplayDlgEx lpfnOpenReplayDlgEx;
typedef INT32	(WINAPI *pAutoAdjustBright)(HANDLE hBoard, LPRECT lpRect, LPVOID dwRes);
pAutoAdjustBright lpfnAutoAdjustBright;
typedef INT32	(WINAPI *pAutoSetCapRect)(HANDLE hBoard, INT32 Width, INT32 Height);
pAutoSetCapRect lpfnAutoSetCapRect;
typedef BOOL	(WINAPI *pOpenSetLUTDlg)(HANDLE hBoard, HWND hWnd, LPVOID lpLUT);
pOpenSetLUTDlg lpfnOpenSetLUTDlg;
typedef BOOL	(WINAPI *pUnifyFields)(HANDLE hBoard, TARGET target, MLONG start);
pUnifyFields lpfnUnifyFields;
typedef INT32	(WINAPI *pDiffusionFilter)(HANDLE hBoard, TARGET target, MLONG start, SHORT nLoop);
pDiffusionFilter lpfnDiffusionFilter;
typedef INT32	(WINAPI *pGuassFilter)(HANDLE hBoard, TARGET target, MLONG start);
pGuassFilter lpfnGuassFilter;
typedef INT32	(WINAPI *pSharpFilter)(HANDLE hBoard, TARGET target, MLONG start, SHORT iClass);
pSharpFilter lpfnSharpFilter;
typedef float	(WINAPI *pGetFocusMeasure)(HANDLE hBoard, TARGET target, MLONG start, LPRECT lpRect, SHORT iMethod, SHORT iPreDegree);
pGetFocusMeasure lpfnGetFocusMeasure;
typedef INT32	(WINAPI *pMultiFrmMean)(HANDLE hBoard, TARGET target, MLONG start, MLONG number);
pMultiFrmMean lpfnMultiFrmMean;
typedef INT32	(WINAPI *pTakeRectMean)(HANDLE hBoard, TARGET target, LPRECT lpRect, MLONG start, short iMode);
pTakeRectMean lpfnTakeRectMean;
typedef INT32	(WINAPI *pEvaluateHistogram)(HANDLE hBoard, TARGET target, LPRECT lpRect, MLONG start, LPDWORD lpHist);
pEvaluateHistogram lpfnEvaluateHistogram;
typedef INT32	(WINAPI *pGetLinExtenMaplut)(LPDWORD lpHist, short iNumBits, short iNumChann, short iIntensity, LPWORD lpwLUT);
pGetLinExtenMaplut lpfnGetLinExtenMaplut;
typedef INT32	(WINAPI *pGetHistEquaMaplut)(LPDWORD lpHist, short iNumBits, short iNumChann, LPWORD lpwLUT);
pGetHistEquaMaplut lpfnGetHistEquaMaplut;
typedef HANDLE	(WINAPI *pBeginEncode)(HANDLE hBoard, DWORD dwCodeWay, MLONG lpImageInfo);
pBeginEncode lpfnBeginEncode;
typedef INT32	(WINAPI *pEncodeImage)(HANDLE hCoder, TARGET src, MLONG start, LPBYTE lpData, MLONG maxlen);
pEncodeImage lpfnEncodeImage;
typedef INT32	(WINAPI *pEndEncode)(HANDLE hCoder);
pEndEncode lpfnEndEncode;
typedef HANDLE	(WINAPI *pBeginDecode)(HANDLE hBoard, DWORD dwCodeWay, LPBYTE lpData, MLONG lpImageInfo);
pBeginDecode lpfnBeginDecode;
typedef INT32	(WINAPI *pDecodeImage)(HANDLE hCoder, LPBYTE lpData, MLONG *length, TARGET target, MLONG start);
pDecodeImage lpfnDecodeImage;
typedef INT32	(WINAPI *pEndDecode)(HANDLE hCoder);
pEndDecode lpfnEndDecode;
typedef BOOL	(WINAPI *pOutputByte)(WORD wport, BYTE data);
pOutputByte lpfnOutputByte;
typedef BYTE	(WINAPI *pInputByte)(WORD wport);
pInputByte lpfnInputByte;
typedef BOOL	(WINAPI *pOutputShort)(WORD wport, SHORT data);
pOutputShort lpfnOutputShort;
typedef SHORT	(WINAPI *pInputShort)(WORD wport);
pInputShort lpfnInputShort;
typedef BOOL	(WINAPI *pOutputLong)(WORD wport, MLONG data);
pOutputLong lpfnOutputLong;
typedef MLONG	(WINAPI *pInputLong)(WORD wport);
pInputLong lpfnInputLong;
typedef BOOL	(WINAPI *pSetPortBase)(WORD wPortBase, SHORT iPortCount);
pSetPortBase lpfnSetPortBase;
typedef SHORT	(WINAPI *pGetGPIOPort)(SHORT index, WORD *wPortBase);
pGetGPIOPort lpfnGetGPIOPort;
typedef DWORD	(WINAPI *pGetAddrForVB)(void *);
pGetAddrForVB lpfnGetAddrForVB;
typedef DWORD	(WINAPI *pGetTickCount)(void );
pGetTickCount lpfnGetTickCount;
typedef void	(WINAPI *pSleep)(DWORD dwMill);
pSleep lpfnSleep;
typedef DWORD	(WINAPI *pGetTickCountMicro)(LPDWORD lpHiDword);
pGetTickCountMicro lpfnGetTickCountMicro;
typedef void	(WINAPI *pSleepMicro)(DWORD dwMicro);
pSleepMicro lpfnSleepMicro;

//------audio section
typedef HANDLE	(WINAPI *pOpenAudio)(HANDLE hBoard, MLONG lParam);
pOpenAudio lpfnOpenAudio;
typedef BOOL	(WINAPI *pCloseAudio)(HANDLE hAudio);
pCloseAudio lpfnCloseAudio;
typedef MLONG	(WINAPI *pCaptureAudio)(HANDLE hAudio, TARGET target, FARPROC lpfnUserProc, MLONG lParam);
pCaptureAudio lpfnCaptureAudio;
typedef BOOL	(WINAPI *pStopCaptureAudio)(HANDLE hAudio);
pStopCaptureAudio lpfnStopCaptureAudio;
typedef INT32	(WINAPI *pSetAudioParam)(HANDLE hAudio, INT32 wParam, INT32 lParam);
pSetAudioParam lpfnSetAudioParam;
typedef INT32	(WINAPI *pReadAudioData)(HANDLE hAudio, LPBYTE lpAudioBuf, INT32 lReadSize);
pReadAudioData lpfnReadAudioData;

//------stream section
typedef HANDLE	(WINAPI *pOpenStream)(HANDLE hBoard, DWORD lParam);
pOpenStream lpfnOpenStream;
typedef BOOL	(WINAPI *pCloseStream)(HANDLE hStream);
pCloseStream lpfnCloseStream;
typedef HANDLE	(WINAPI *pCaptureStream)(HANDLE hStream, TARGET target, FARPROC lpfnUserProc, MLONG lMiliseconds);
pCaptureStream lpfnCaptureStream;
typedef BOOL	(WINAPI *pStopCaptureStream)(HANDLE hStream, DWORD dwPause);
pStopCaptureStream lpfnStopCaptureStream;
typedef MLONG	(WINAPI *pSetStreamParam)(HANDLE hStream, INT32 wParam, MLONG lParam);
pSetStreamParam lpfnSetStreamParam;
typedef INT32	(WINAPI *pReadStreamData)(HANDLE hStream, LPBYTE lpStreamBuf, INT32 lReadSize);
pReadStreamData lpfnReadStreamData;
typedef MLONG	(WINAPI	*pGetCurrStream)(HANDLE hStream, LPVOID lParam);
pGetCurrStream lpfnGetCurrStream;

//-------serial section
typedef INT32	(WINAPI *pSetSerial)(HANDLE hBoard, INT32 wParam, INT32 lParam);
pSetSerial lpfnSetSerial;
typedef INT32	(WINAPI *pReadSerial)(HANDLE hBoard, LPVOID lpBuffer, INT32 lSize, MLONG lTimeOut);
pReadSerial lpfnReadSerial;
typedef BOOL	(WINAPI *pWriteSerial)(HANDLE hBoard, LPVOID lpBuffer, INT32 lSize, MLONG lTimeOut);
pWriteSerial lpfnWriteSerial;


/*-----------------------------------------------------------------------------
*       Functions Process
*/


//2. section

static int		iLoadNum=0;
static HMODULE  	hDLLDrv=0;

BOOL LoadOkApiDll(BOOL bCount)
{
#if defined(Q_OS_WIN32)
    if(!hDLLDrv)
        hDLLDrv=LoadLibrary(TEXT(DLLNAME));
#else
    if(!hDLLDrv)
        hDLLDrv=LoadLibrary(DLLNAME);
#endif

	if(!hDLLDrv) //not found
		return FALSE;

	if(iLoadNum==0) {
        lpfnOpenBoard=(pOpenBoard)GetProcAddress(hDLLDrv,"okOpenBoard");
        lpfnOpenBoardEx=(pOpenBoardEx)GetProcAddress(hDLLDrv,"okOpenBoardEx");
        lpfnCloseBoard=(pCloseBoard)GetProcAddress(hDLLDrv,"okCloseBoard");
        lpfnGetLastError=(pGetLastError)GetProcAddress(hDLLDrv,"okGetLastError");
        lpfnGetBufferSize=(pGetBufferSize)GetProcAddress(hDLLDrv,"okGetBufferSize");
        lpfnGetBufferAddr=(pGetBufferAddr)GetProcAddress(hDLLDrv,"okGetBufferAddr");
        lpfnGetTargetInfo=(pGetTargetInfo)GetProcAddress(hDLLDrv,"okGetTargetInfo");

        lpfnGetTypeCode=(pGetTypeCode)GetProcAddress(hDLLDrv,"okGetTypeCode");
        lpfnGetNetDevNumber=(pGetNetDevNumber)GetProcAddress(hDLLDrv,"okGetNetDevNumber");

        lpfnSetTargetRect=(pSetTargetRect)GetProcAddress(hDLLDrv,"okSetTargetRect");
        lpfnSetToWndRect=(pSetToWndRect)GetProcAddress(hDLLDrv,"okSetToWndRect");
        lpfnSetVideoParam=(pSetVideoParam)GetProcAddress(hDLLDrv,"okSetVideoParam");
        lpfnSetCaptureParam=(pSetCaptureParam)GetProcAddress(hDLLDrv,"okSetCaptureParam");
        lpfnSetDeviceParam=(pSetDeviceParam)GetProcAddress(hDLLDrv,"okSetDeviceParam");

        lpfnCaptureTo=(pCaptureTo)GetProcAddress(hDLLDrv,"okCaptureTo");
        lpfnCaptureSingle=(pCaptureSingle)GetProcAddress(hDLLDrv,"okCaptureSingle");
        lpfnCaptureActive=(pCaptureActive)GetProcAddress(hDLLDrv,"okCaptureActive");
        lpfnCaptureThread=(pCaptureThread)GetProcAddress(hDLLDrv,"okCaptureThread");
        lpfnCaptureSequence=(pCaptureSequence)GetProcAddress(hDLLDrv,"okCaptureSequence");
        lpfnCaptureToScreen=(pCaptureToScreen)GetProcAddress(hDLLDrv,"okCaptureToScreen");
        lpfnPlaybackFrom=(pPlaybackFrom)GetProcAddress(hDLLDrv,"okPlaybackFrom");
        lpfnPlaybackSequence=(pPlaybackSequence)GetProcAddress(hDLLDrv,"okPlaybackSequence");
        lpfnSetDriverParam=(pSetDriverParam)GetProcAddress(hDLLDrv,"okSetDriverParam");
        lpfnGetCaptureStatus=(pGetCaptureStatus)GetProcAddress(hDLLDrv,"okGetCaptureStatus");
        lpfnGetLineReady=(pGetLineReady)GetProcAddress(hDLLDrv,"okGetLineReady");

        lpfnStopCapture=(pStopCapture)GetProcAddress(hDLLDrv,"okStopCapture");

        lpfnGetSeqCapture=(pGetSeqCapture)GetProcAddress(hDLLDrv,"okGetSeqCapture");

        lpfnCaptureByBuffer=(pCaptureByBuffer)GetProcAddress(hDLLDrv,"okCaptureByBuffer");
        lpfnCaptureByBufferEx=(pCaptureByBufferEx)GetProcAddress(hDLLDrv,"okCaptureByBufferEx");
        lpfnPlaybackByBuffer=(pPlaybackByBuffer)GetProcAddress(hDLLDrv,"okPlaybackByBuffer");

        lpfnReadPixel=(pReadPixel)GetProcAddress(hDLLDrv,"okReadPixel");
        lpfnWritePixel=(pWritePixel)GetProcAddress(hDLLDrv,"okWritePixel");
        lpfnSetConvertParam=(pSetConvertParam)GetProcAddress(hDLLDrv,"okSetConvertParam");
        lpfnReadRect=(pReadRect)GetProcAddress(hDLLDrv,"okReadRect");
        lpfnWriteRect=(pWriteRect)GetProcAddress(hDLLDrv,"okWriteRect");
        lpfnTransferRect=(pTransferRect)GetProcAddress(hDLLDrv,"okTransferRect");
        lpfnConvertRect=(pConvertRect)GetProcAddress(hDLLDrv,"okConvertRect");
        lpfnConvertRectEx=(pConvertRectEx)GetProcAddress(hDLLDrv,"okConvertRectEx");
        lpfnReadRectEx=(pReadRectEx)GetProcAddress(hDLLDrv,"okReadRectEx");
        lpfnWriteRectEx=(pWriteRectEx)GetProcAddress(hDLLDrv,"okWriteRectEx");
#if defined(Q_OS_WIN32)
        lpfnSetTextTo=(pSetTextTo)GetProcAddress(hDLLDrv,"okSetTextTo");
#endif
        lpfnDrawLineTo=(pDrawLineTo)GetProcAddress(hDLLDrv,"okDrawLineTo");
        lpfnDrawEllipsTo=(pDrawEllipsTo)GetProcAddress(hDLLDrv,"okDrawEllipsTo");
        lpfnFillCircleTo=(pFillCircleTo)GetProcAddress(hDLLDrv,"okFillCircleTo");

        lpfnCreateDCBitmap=(pCreateDCBitmap)GetProcAddress(hDLLDrv,"okCreateDCBitmap");
        lpfnMapDCBitmapTo=(pMapDCBitmapTo)GetProcAddress(hDLLDrv,"okMapDCBitmapTo");
        lpfnFreeDCBitmap=(pFreeDCBitmap)GetProcAddress(hDLLDrv,"okFreeDCBitmap");

        lpfnWaitVerticalSync=(pWaitVerticalSync)GetProcAddress(hDLLDrv,"okWaitVerticalSync");


        lpfnGetSignalParam=(pGetSignalParam)GetProcAddress(hDLLDrv,"okGetSignalParam");
        lpfnWaitSignalEvent=(pWaitSignalEvent)GetProcAddress(hDLLDrv,"okWaitSignalEvent");
        lpfnPutSignalParam=(pPutSignalParam)GetProcAddress(hDLLDrv,"okPutSignalParam");

        lpfnSetUserData=(pSetUserData)GetProcAddress(hDLLDrv,"okSetUserData");
        lpfnSetSeqProcWnd=(pSetSeqProcWnd)GetProcAddress(hDLLDrv,"okSetSeqProcWnd");

        lpfnSetSeqCallback=(pSetSeqCallback)GetProcAddress(hDLLDrv,"okSetSeqCallback");
        lpfnSetEventCallback=(pSetEventCallback)GetProcAddress(hDLLDrv,"okSetEventCallback");
        lpfnSetCloseCallback=(pSetCloseCallback)GetProcAddress(hDLLDrv,"okSetCloseCallback");

        lpfnEnableMask=(pEnableMask)GetProcAddress(hDLLDrv,"okEnableMask");
        lpfnSetMaskRect=(pSetMaskRect)GetProcAddress(hDLLDrv,"okSetMaskRect");
        lpfnFillOutLUT=(pFillOutLUT)GetProcAddress(hDLLDrv,"okFillOutLUT");
        lpfnFillInputLUT=(pFillInputLUT)GetProcAddress(hDLLDrv,"okFillInputLUT");

        lpfnGetImageDevice=(pGetImageDevice)GetProcAddress(hDLLDrv,"okGetImageDevice");
        lpfnGetSlotBoard=(pGetSlotBoard)GetProcAddress(hDLLDrv,"okGetSlotBoard");
        lpfnGetBoardIndex=(pGetBoardIndex)GetProcAddress(hDLLDrv,"okGetBoardIndex");
        lpfnGetBoardName=(pGetBoardName)GetProcAddress(hDLLDrv,"okGetBoardName");

        lpfnGetAvailBuffer=(pGetAvailBuffer)GetProcAddress(hDLLDrv,"okGetAvailBuffer");
        lpfnLockBuffer=(pLockBuffer)GetProcAddress(hDLLDrv,"okLockBuffer");
        lpfnUnlockAllBuffer=(pUnlockAllBuffer)GetProcAddress(hDLLDrv,"okUnlockAllBuffer");

        lpfnApplyMemBlock=(pApplyMemBlock)GetProcAddress(hDLLDrv,"okApplyMemBlock");
        lpfnFreeMemBlock=(pFreeMemBlock)GetProcAddress(hDLLDrv,"okFreeMemBlock");
        lpfnGetMemBlock=(pGetMemBlock)GetProcAddress(hDLLDrv,"okGetMemBlock");
        lpfnLockMemBlock=(pLockMemBlock)GetProcAddress(hDLLDrv,"okLockMemBlock");
        lpfnUnlockMemBlock=(pUnlockMemBlock)GetProcAddress(hDLLDrv,"okUnlockMemBlock");

        lpfnMulCaptureTo=(pMulCaptureTo)GetProcAddress(hDLLDrv,"okMulCaptureTo");
        lpfnMulCaptureByBuffer=(pMulCaptureByBuffer)GetProcAddress(hDLLDrv,"okMulCaptureByBuffer");

        lpfnSaveInitParam=(pSaveInitParam)GetProcAddress(hDLLDrv,"okSaveInitParam");
        lpfnLoadInitParam=(pLoadInitParam)GetProcAddress(hDLLDrv,"okLoadInitParam");

        lpfnSetAllocBuffer=(pSetAllocBuffer)GetProcAddress(hDLLDrv,"okSetAllocBuffer");
        lpfnSetStaticVxD=(pSetStaticVxD)GetProcAddress(hDLLDrv,"okSetStaticVxD");
        lpfnSetNTDriver=(pSetNTDriver)GetProcAddress(hDLLDrv,"okSetNTDriver");
        lpfnSetLangResource=(pSetLangResource)GetProcAddress(hDLLDrv,"okSetLangResource");


        lpfnUnRegister=(pUnRegister)GetProcAddress(hDLLDrv,"okUnRegister");
        lpfnGetProgramInfo=(pGetProgramInfo)GetProcAddress(hDLLDrv,"okGetProgramInfo");

        lpfnReadProtCode=(pReadProtCode)GetProcAddress(hDLLDrv,"okReadProtCode");
        lpfnWriteProtCode=(pWriteProtCode)GetProcAddress(hDLLDrv,"okWriteProtCode");

        lpfnSaveImageFile=(pSaveImageFile)GetProcAddress(hDLLDrv,"okSaveImageFile");
        lpfnLoadImageFile=(pLoadImageFile)GetProcAddress(hDLLDrv,"okLoadImageFile");
        lpfnGetCurrImageInfo=(pGetCurrImageInfo)GetProcAddress(hDLLDrv,"okGetCurrImageInfo");


        lpfnLoadConfigFile=(pLoadConfigFile)GetProcAddress(hDLLDrv,"okLoadConfigFile");
        lpfnSaveConfigFile=(pSaveConfigFile)GetProcAddress(hDLLDrv,"okSaveConfigFile");

        lpfnLoadFlatModelFile=(pLoadFlatModelFile)GetProcAddress(hDLLDrv,"okLoadFlatModelFile");
        lpfnSaveFlatModelFile=(pSaveFlatModelFile)GetProcAddress(hDLLDrv,"okSaveFlatModelFile");

        lpfnOpenSetParamDlg=(pOpenSetParamDlg)GetProcAddress(hDLLDrv,"okOpenSetParamDlg");
        lpfnOpenSeqCaptureDlg=(pOpenSeqCaptureDlg)GetProcAddress(hDLLDrv,"okOpenSeqCaptureDlg");
        lpfnOpenReplayDlg=(pOpenReplayDlg)GetProcAddress(hDLLDrv,"okOpenReplayDlg");
        lpfnOpenReplayDlgEx=(pOpenReplayDlgEx)GetProcAddress(hDLLDrv,"okOpenReplayDlgEx");
        lpfnAutoAdjustBright=(pAutoAdjustBright)GetProcAddress(hDLLDrv,"okAutoAdjustBright");
        lpfnAutoSetCapRect=(pAutoSetCapRect)GetProcAddress(hDLLDrv,"okAutoSetCapRect");
        lpfnOpenSetLUTDlg=(pOpenSetLUTDlg)GetProcAddress(hDLLDrv,"okOpenSetLUTDlg");

        lpfnUnifyFields=(pUnifyFields)GetProcAddress(hDLLDrv,"okUnifyFields");
        lpfnDiffusionFilter=(pDiffusionFilter)GetProcAddress(hDLLDrv,"okDiffusionFilter");
        lpfnGuassFilter=(pGuassFilter)GetProcAddress(hDLLDrv,"okGuassFilter");
        lpfnSharpFilter=(pSharpFilter)GetProcAddress(hDLLDrv,"okSharpFilter");
        lpfnGetFocusMeasure=(pGetFocusMeasure)GetProcAddress(hDLLDrv,"okGetFocusMeasure");
        lpfnMultiFrmMean=(pMultiFrmMean)GetProcAddress(hDLLDrv,"okMultiFrmMean");
        lpfnTakeRectMean=(pTakeRectMean)GetProcAddress(hDLLDrv,"okTakeRectMean");
        lpfnEvaluateHistogram=(pEvaluateHistogram)GetProcAddress(hDLLDrv,"okEvaluateHistogram");
        lpfnGetLinExtenMaplut=(pGetLinExtenMaplut)GetProcAddress(hDLLDrv,"okGetLinExtenMaplut");
        lpfnGetHistEquaMaplut=(pGetHistEquaMaplut)GetProcAddress(hDLLDrv,"okGetHistEquaMaplut");

        lpfnBeginEncode=(pBeginEncode)GetProcAddress(hDLLDrv,"okBeginEncode");
        lpfnEncodeImage=(pEncodeImage)GetProcAddress(hDLLDrv,"okEncodeImage");
        lpfnEndEncode=(pEndEncode)GetProcAddress(hDLLDrv,"okEndEncode");
        lpfnBeginDecode=(pBeginDecode)GetProcAddress(hDLLDrv,"okBeginDecode");
        lpfnDecodeImage=(pDecodeImage)GetProcAddress(hDLLDrv,"okDecodeImage");
        lpfnEndDecode=(pEndDecode)GetProcAddress(hDLLDrv,"okEndDecode");


        lpfnOutputByte=(pOutputByte)GetProcAddress(hDLLDrv,"okOutputByte");
        lpfnInputByte=(pInputByte)GetProcAddress(hDLLDrv,"okInputByte");
        lpfnOutputShort=(pOutputShort)GetProcAddress(hDLLDrv,"okOutputShort");
        lpfnInputShort=(pInputShort)GetProcAddress(hDLLDrv,"okInputShort");
        lpfnOutputLong=(pOutputLong)GetProcAddress(hDLLDrv,"okOutputLong");
        lpfnInputLong=(pInputLong)GetProcAddress(hDLLDrv,"okInputLong");

        lpfnSetPortBase=(pSetPortBase)GetProcAddress(hDLLDrv,"okSetPortBase");
        lpfnGetGPIOPort=(pGetGPIOPort)GetProcAddress(hDLLDrv,"okGetGPIOPort");

        lpfnGetAddrForVB=(pGetAddrForVB)GetProcAddress(hDLLDrv,"okGetAddrForVB");
        lpfnGetTickCount=(pGetTickCount)GetProcAddress(hDLLDrv,"okGetTickCount");
        lpfnSleep=(pSleep)GetProcAddress(hDLLDrv,"okSleep");
        lpfnGetTickCountMicro=(pGetTickCountMicro)GetProcAddress(hDLLDrv,"okGetTickCountMicro");
        lpfnSleepMicro=(pSleepMicro)GetProcAddress(hDLLDrv,"okSleepMicro");


		//---audio
        lpfnOpenAudio=(pOpenAudio)GetProcAddress(hDLLDrv,"okOpenAudio");
        lpfnCloseAudio=(pCloseAudio)GetProcAddress(hDLLDrv,"okCloseAudio");
        lpfnCaptureAudio=(pCaptureAudio)GetProcAddress(hDLLDrv,"okCaptureAudio");
        lpfnStopCaptureAudio=(pStopCaptureAudio)GetProcAddress(hDLLDrv,"okStopCaptureAudio");
        lpfnSetAudioParam=(pSetAudioParam)GetProcAddress(hDLLDrv,"okSetAudioParam");
        lpfnReadAudioData=(pReadAudioData)GetProcAddress(hDLLDrv,"okReadAudioData");

		//---stream
        lpfnOpenStream=(pOpenStream)GetProcAddress(hDLLDrv,"okOpenStream");
        lpfnCloseStream=(pCloseStream)GetProcAddress(hDLLDrv,"okCloseStream");
        lpfnCaptureStream=(pCaptureStream)GetProcAddress(hDLLDrv,"okCaptureStream");
        lpfnStopCaptureStream=(pStopCaptureStream)GetProcAddress(hDLLDrv,"okStopCaptureStream");
        lpfnSetStreamParam=(pSetStreamParam)GetProcAddress(hDLLDrv,"okSetStreamParam");
        lpfnReadStreamData=(pReadStreamData)GetProcAddress(hDLLDrv,"okReadStreamData");
        lpfnGetCurrStream=(pGetCurrStream)GetProcAddress(hDLLDrv,"okGetCurrStream");

		//---serial
        lpfnSetSerial=(pSetSerial)GetProcAddress(hDLLDrv,"okSetSerial");
        lpfnReadSerial=(pReadSerial)GetProcAddress(hDLLDrv,"okReadSerial");
        lpfnWriteSerial=(pWriteSerial)GetProcAddress(hDLLDrv,"okWriteSerial");
		
	}

	if(bCount || (iLoadNum==0) )
	//if( (iLoadNum==0) )
		iLoadNum++;

	return TRUE;
}

int FreeOkApiDll()
{
	iLoadNum--;
	if(iLoadNum<=0) {
		FreeLibrary(hDLLDrv);
		hDLLDrv=0;
	}
	return 1;
}

FARPROC GetProcPointer(LPSTR lpszName)
{
#if defined(Q_OS_WIN32)
	if(!hDLLDrv)
        hDLLDrv=LoadLibrary(TEXT(DLLNAME));
#else
    if(!hDLLDrv)
        hDLLDrv=LoadLibrary(DLLNAME);
#endif
    return GetProcAddress(hDLLDrv,lpszName);
}


HANDLE	WINAPI okOpenBoard(MLONG *iIndex) 
{
	LoadOkApiDll(1);

	return lpfnOpenBoard(iIndex);
}

HANDLE	WINAPI okOpenBoardEx(MLONG *iIndex, HANDLE hParBoard, LPVOID lParam) 
{
	LoadOkApiDll(1);

	return lpfnOpenBoardEx(iIndex, hParBoard, lParam);
}


BOOL	WINAPI okCloseBoard(HANDLE hBoard)
{
	BOOL	ret=0;

	if(hDLLDrv)
		ret=lpfnCloseBoard(hBoard);

	if(ret)
		FreeOkApiDll();

	return ret;
}


//3. sections

INT32	WINAPI okGetLastError(void )
{	
    lpfnGetLastError=(pGetLastError)GetProcPointer((LPSTR)"okGetLastError");
    return lpfnGetLastError();
}

MLONG	WINAPI okGetBufferSize(HANDLE hBoard, void **lpLinear, MWORD *dwSize)
{	
    lpfnGetBufferSize=(pGetBufferSize)GetProcPointer((LPSTR)"okGetBufferSize");
    return lpfnGetBufferSize(hBoard, lpLinear, dwSize);
}


LPVOID	WINAPI okGetBufferAddr(HANDLE hBoard, MLONG iNoFrame)
{	return lpfnGetBufferAddr(hBoard, iNoFrame);	}

LPVOID	WINAPI okGetTargetInfo(HANDLE hBoard, TARGET tgt, MLONG lNoFrame, SHORT * wid, SHORT * ht, MLONG *stride)
{	return lpfnGetTargetInfo(hBoard, tgt, lNoFrame, wid, ht, stride);	}

INT32	WINAPI okGetTypeCode(HANDLE hBoard,LPSTR lpBoardName)
{	return lpfnGetTypeCode(hBoard,lpBoardName);	}

INT32	WINAPI okGetNetDevNumber(INT32 iTypeCode, LPSTR lpNameString)
{	return lpfnGetNetDevNumber(iTypeCode,lpNameString);}

MLONG	WINAPI okSetTargetRect(HANDLE hBoard, TARGET target, LPRECT lpTgtRect)
{	return lpfnSetTargetRect(hBoard, target, lpTgtRect);	}

INT32	WINAPI okSetToWndRect(HANDLE hBoard, HWND hWnd)
{	return lpfnSetToWndRect(hBoard, hWnd);	}

MLONG	WINAPI okCaptureTo(HANDLE hBoard, TARGET Dest, MLONG start, MLONG lParam)
{	return lpfnCaptureTo(hBoard, Dest, start, lParam);	}

BOOL	WINAPI okCaptureSingle(HANDLE hBoard, TARGET Dest, MLONG lStart)
{	return lpfnCaptureSingle(hBoard, Dest, lStart);	}

BOOL	WINAPI okCaptureActive(HANDLE hBoard, TARGET Dest, MLONG lStart)
{	return lpfnCaptureActive(hBoard, Dest, lStart);	}

HANDLE	WINAPI okCaptureThread(HANDLE hBoard, TARGET Dest, MLONG lStart, MLONG lNoFrame)
{	return lpfnCaptureThread(hBoard, Dest, lStart, lNoFrame);	}

BOOL	WINAPI okCaptureSequence(HANDLE hBoard, MLONG lStart, MLONG lNoFrame)
{	return lpfnCaptureSequence(hBoard, lStart, lNoFrame);	}

MLONG	WINAPI okCaptureToScreen(HANDLE hBoard)
{	return lpfnCaptureToScreen(hBoard);	}

MLONG	WINAPI okPlaybackFrom(HANDLE hBoard, TARGET src, MLONG start, MLONG lParam)
{	return lpfnPlaybackFrom(hBoard, src, start, lParam);	}

BOOL	WINAPI okPlaybackSequence(HANDLE hBoard, MLONG lstart, MLONG lNoFrame)
{	return lpfnPlaybackSequence(hBoard, lstart, lNoFrame);	}

MLONG	WINAPI okSetDriverParam(INT32 lWhich, MLONG lParam)
{	return lpfnSetDriverParam(lWhich, lParam);}

MLONG	WINAPI okGetCaptureStatus(HANDLE hBoard, BOOL bWait)
{	return lpfnGetCaptureStatus(hBoard, bWait);	}

MLONG	WINAPI okGetLineReady(HANDLE hBoard, MLONG *iCurrFrameNo, MWORD dwRes)
{	return lpfnGetLineReady(hBoard, iCurrFrameNo, dwRes);	}



MLONG	WINAPI okStopCapture(HANDLE hBoard)
{	return lpfnStopCapture(hBoard);	}

HANDLE	WINAPI okCaptureByBuffer(HANDLE hBoard, TARGET dest, MLONG start, MLONG num)
{	return lpfnCaptureByBuffer(hBoard, dest, start, num);	}

MLONG	WINAPI okGetSeqCapture(HANDLE hBoard, MLONG start, MLONG count)
{	return lpfnGetSeqCapture(hBoard, start, count);	}


HANDLE	WINAPI okCaptureByBufferEx(HANDLE hBoard, MLONG fileset, TARGET dest, MLONG start, MLONG num)
{	return lpfnCaptureByBufferEx(hBoard, fileset, dest, start, num);	}

HANDLE	WINAPI okPlaybackByBuffer(HANDLE hBoard, TARGET src, MLONG start, MLONG num)
{	return lpfnPlaybackByBuffer(hBoard, src, start, num);	}

MLONG	WINAPI okSetVideoParam(HANDLE hBoard, INT32 wParam, MLONG lParam)
{	return lpfnSetVideoParam(hBoard, wParam, lParam);	}

MLONG	WINAPI okSetCaptureParam(HANDLE hBoard, INT32 wParam, MLONG lParam)
{	return lpfnSetCaptureParam(hBoard, wParam, lParam);	}

MLONG	WINAPI okSetDeviceParam(HANDLE hBoard, INT32 wParam, MLONG lParam)
{	return lpfnSetDeviceParam(hBoard, wParam, lParam);	}


INT32	WINAPI okReadPixel(HANDLE  hBoard, TARGET src, MLONG start, SHORT x, SHORT y)
{	return lpfnReadPixel(hBoard, src, start, x, y);	}

INT32	WINAPI okWritePixel(HANDLE  hBoard, TARGET src, MLONG start, SHORT x, SHORT y, INT32 lvalue)
{	return lpfnWritePixel(hBoard, src, start, x, y, lvalue);	}

MLONG	WINAPI okSetConvertParam(HANDLE hBoard, INT32 wParam, MLONG lParam)
{	return lpfnSetConvertParam(hBoard, wParam, lParam);	}

INT32	WINAPI okReadRect(HANDLE  hBoard, TARGET src, MLONG start, LPBYTE lpBuf)
{	return lpfnReadRect(hBoard, src, start, lpBuf);	}

INT32	WINAPI okWriteRect(HANDLE  hBoard, TARGET dst, MLONG start, LPBYTE lpBuf)
{	return lpfnWriteRect(hBoard, dst, start, lpBuf);	}

INT32	WINAPI okTransferRect(HANDLE hBoard, TARGET dest, MLONG iFirst, TARGET src, MLONG iStart, MLONG lNum)
{	return lpfnTransferRect(hBoard, dest, iFirst, src, iStart, lNum);	}

INT32	WINAPI okConvertRect(HANDLE hBoard, TARGET dst, MLONG first, TARGET src, MLONG start, MLONG no)
{	return lpfnConvertRect(hBoard, dst, first, src, start, no);	}

INT32	WINAPI okConvertRectEx(HANDLE hDstBoard, TARGET dst, MLONG first, HANDLE hSrcBoard, TARGET src, MLONG start, MLONG no)
{	return lpfnConvertRectEx(hDstBoard, dst, first, hSrcBoard, src, start, no);	}

INT32	WINAPI okReadRectEx(HANDLE hBoard, TARGET src, MLONG start, LPBYTE lpBuf, INT32 lParam)
{	return lpfnReadRectEx(hBoard, src, start, lpBuf, lParam);	}

INT32	WINAPI okWriteRectEx(HANDLE hBoard, TARGET dst, MLONG start, LPBYTE lpBuf, INT32 lParam)
{	return lpfnWriteRectEx(hBoard, dst, start, lpBuf, lParam);	}

#if defined(Q_OS_WIN32)
BOOL	WINAPI okSetTextTo(HANDLE hBoard, TARGET target, LPRECT lpRect, LOGFONT *lfLogFont, SETTEXTMODE *textMode, LPSTR lpString, INT32 lLength)
{	return lpfnSetTextTo( hBoard, target, lpRect, lfLogFont, textMode, lpString, lLength);	}
#endif

INT32	WINAPI okDrawLineTo(HANDLE hBoard, TARGET target, MLONG lStart, POINT pt0, POINT pt1, INT32 iForeColor)
{	return lpfnDrawLineTo(hBoard, target, lStart, pt0, pt1, iForeColor);	}

INT32	WINAPI okDrawEllipsTo(HANDLE hBoard, TARGET target, MLONG lStart, LPRECT lpRect, INT32 iForeColor)
{	return lpfnDrawEllipsTo(hBoard, target, lStart, lpRect, iForeColor);	}

INT32	WINAPI okFillCircleTo(HANDLE hBoard, TARGET target, MLONG lStart, LPRECT lpRect, INT32 iForeColor, INT32 lMode)
{	return lpfnFillCircleTo(hBoard, target, lStart, lpRect, iForeColor, lMode);	}


HDC		WINAPI okCreateDCBitmap(HANDLE hBoard, TARGET target, HANDLE *hDCBitmap)
{	return lpfnCreateDCBitmap(hBoard, target, hDCBitmap);	}

BOOL	WINAPI okMapDCBitmapTo(HANDLE hDCBitmap, MLONG lStart)
{	return lpfnMapDCBitmapTo(hDCBitmap, lStart);	}

BOOL	WINAPI okFreeDCBitmap(HANDLE hDCBitmap)
{	return lpfnFreeDCBitmap(hDCBitmap);	}

BOOL	WINAPI okWaitVerticalSync(HANDLE hBoard, BOOL bHeader)
{	return lpfnWaitVerticalSync(hBoard, bHeader);	}



INT32	WINAPI okGetSignalParam(HANDLE hBoard, INT32 wParam)
{	return lpfnGetSignalParam(hBoard, wParam);	}

INT32	WINAPI okWaitSignalEvent(HANDLE hBoard, INT32 wParam, MLONG lMilliSecond)
{	return lpfnWaitSignalEvent(hBoard, wParam, lMilliSecond);	}

MLONG	WINAPI okPutSignalParam(HANDLE hBoard, INT32 wParam, MLONG lParam)
{	return lpfnPutSignalParam(hBoard, wParam, lParam);	}


MLONG	WINAPI okSetUserData(HANDLE hBoard, MLONG lUserData)
{	return lpfnSetUserData(hBoard, lUserData);	}

BOOL	WINAPI okSetSeqProcWnd(HANDLE hBoard, HWND hwndMain)
{	return lpfnSetSeqProcWnd(hBoard, hwndMain);	}


BOOL	WINAPI okSetSeqCallback(HANDLE hBoard, 
								BOOL CALLBACK BeginProc(HANDLE hBoard), 
								BOOL CALLBACK SeqProc(HANDLE hBoard, MLONG No), 
								BOOL CALLBACK EndProc(HANDLE hBoard))
{	return lpfnSetSeqCallback(hBoard, BeginProc, SeqProc, EndProc);	}

BOOL	WINAPI okSetEventCallback(HANDLE hBoard, INT32 iEvent, BOOL CALLBACK EventProc(HANDLE hBoard, MWORD dwReserved) )
{
	return lpfnSetEventCallback(hBoard,iEvent,EventProc);
}

BOOL	WINAPI okSetCloseCallback(HANDLE hBoard,
								  BOOL CALLBACK CloseProc(HANDLE hBoard, MWORD dwReserved) 	)
{
	return lpfnSetCloseCallback(hBoard, CloseProc);	
}


INT32	WINAPI okEnableMask(HANDLE hBoard, BOOL bMask)
{	return lpfnEnableMask(hBoard, bMask);	}

INT32	WINAPI okSetMaskRect(HANDLE hBoard, LPRECT lpRect, LPBYTE lpMask)
{	return lpfnSetMaskRect(hBoard, lpRect, lpMask);	}


INT32	WINAPI okFillOutLUT(HANDLE hBoard,  LPVOID bLUT, INT32 start, INT32 num)
{	return lpfnFillOutLUT(hBoard,  bLUT, start, num);	}

INT32	WINAPI okFillInputLUT(HANDLE hBoard,  LPVOID bLUT, INT32 start, INT32 num)
{	return lpfnFillInputLUT(hBoard,  bLUT, start, num);	}



INT32	WINAPI okGetImageDevice(OKDEVTYPE **lpOkDevInfo, MLONG lpParam)
{
    lpfnGetImageDevice=(pGetImageDevice)GetProcPointer((LPSTR)"okGetImageDevice");
    return lpfnGetImageDevice(lpOkDevInfo, lpParam);
}

SHORT	WINAPI okGetSlotBoard(BOARDTYPE **lpOkInfo)
{
    lpfnGetSlotBoard=(pGetSlotBoard)GetProcPointer((LPSTR)"okGetSlotBoard");
	return lpfnGetSlotBoard(lpOkInfo);	}

SHORT	WINAPI okGetBoardIndex(CHAR *szBoardName, SHORT iNo)
{
    lpfnGetBoardIndex=(pGetBoardIndex)GetProcPointer((LPSTR)"okGetBoardIndex");
	return lpfnGetBoardIndex(szBoardName, iNo);	}


INT32	WINAPI okGetBoardName(SHORT lIndex, LPSTR szBoardName)
{
    lpfnGetBoardName=(pGetBoardName)GetProcPointer((LPSTR)"okGetBoardName");
	return lpfnGetBoardName(lIndex, szBoardName);	}


MLONG	WINAPI okGetAvailBuffer(void **lpLinear, MWORD *dwSize)
{
    lpfnGetAvailBuffer=(pGetAvailBuffer)GetProcPointer((LPSTR)"okGetAvailBuffer");
	return lpfnGetAvailBuffer(lpLinear, dwSize);	}

MLONG	WINAPI okLockBuffer(HANDLE hBoard, MWORD dwSizeByte, void **lpBasLinear)
{	return lpfnLockBuffer(hBoard, dwSizeByte, lpBasLinear);	}

BOOL	WINAPI okUnlockAllBuffer(void)
{	return lpfnUnlockAllBuffer();	}


INT32	WINAPI okApplyMemBlock(DWORD dwBlockSize, DWORD dwBlockNo)
{	lpfnApplyMemBlock=(pApplyMemBlock)GetProcPointer((LPSTR)"okApplyMemBlock");
	return lpfnApplyMemBlock(dwBlockSize, dwBlockNo);	}

BOOL	WINAPI okFreeMemBlock(void)
{	return lpfnFreeMemBlock();	}

INT32	WINAPI okGetMemBlock(HANDLE hBoard, DWORD *dwEachSize,  DWORD *dwBlockNo)
{	return lpfnGetMemBlock(hBoard, dwEachSize,  dwBlockNo);	}

INT32	WINAPI okLockMemBlock(HANDLE hBoard, DWORD dwBlockNo)
{	return lpfnLockMemBlock(hBoard, dwBlockNo);	}

BOOL	WINAPI okUnlockMemBlock(void)
{	return lpfnUnlockMemBlock();	}



MLONG	WINAPI okMulCaptureTo(HANDLE *lphBoard, TARGET Dest, MLONG start, MLONG lParam)
{	return lpfnMulCaptureTo(lphBoard, Dest, start, lParam);	}

HANDLE	WINAPI okMulCaptureByBuffer(HANDLE *lphBoard, TARGET tgt, MLONG start, MLONG num)
{	return lpfnMulCaptureByBuffer(lphBoard, tgt, start, num);	}


MLONG	WINAPI okSetAllocBuffer(MLONG lSize)
{
    lpfnSetAllocBuffer=(pSetAllocBuffer)GetProcPointer((LPSTR)"okSetAllocBuffer");
	return lpfnSetAllocBuffer(lSize);	
}

BOOL	WINAPI okSetStaticVxD(INT32 lMode)
{
    lpfnSetStaticVxD=(pSetStaticVxD)GetProcPointer((LPSTR)"okSetStaticVxD");
	return lpfnSetStaticVxD(lMode);	
}

BOOL	WINAPI okSetNTDriver(BOOL bCmd)
{
    lpfnSetNTDriver=(pSetNTDriver)GetProcPointer((LPSTR)"okSetNTDriver");
	return lpfnSetNTDriver(bCmd);	
}

INT32	WINAPI okSetLangResource(INT32 langcode)
{
    lpfnSetLangResource=(pSetLangResource)GetProcPointer((LPSTR)"okSetLangResource");
	return lpfnSetLangResource(langcode);	
}


BOOL	WINAPI okUnRegister(DWORD dwCmd)
{	
    lpfnUnRegister=(pUnRegister)GetProcPointer((LPSTR)"okUnRegister");
	return lpfnUnRegister(dwCmd);	
}

INT32	WINAPI okGetProgramInfo(INT32 iItem, LPSTR lpString, INT32 iSize)
{	
    lpfnGetProgramInfo=(pGetProgramInfo)GetProcPointer((LPSTR)"okGetProgramInfo");
	return lpfnGetProgramInfo(iItem, lpString, iSize);
}


BOOL	WINAPI okSaveInitParam(HANDLE hBoard, SHORT iChannNo)
{	return lpfnSaveInitParam(hBoard, iChannNo);	}

BOOL	WINAPI okLoadInitParam(HANDLE hBoard, SHORT iChannNo)
{	return lpfnLoadInitParam(hBoard, iChannNo);	}

INT32	WINAPI okReadProtCode(HANDLE hBoard, SHORT iIndex)
{	return lpfnReadProtCode(hBoard, iIndex);	}

INT32	WINAPI okWriteProtCode(HANDLE hBoard, SHORT iIndex, INT32 Code)
{	return lpfnWriteProtCode(hBoard, iIndex, Code);	}



MLONG WINAPI okSaveImageFile(HANDLE hBoard, LPSTR szFileName, MLONG first, TARGET target, MLONG start, MLONG num)
{	return lpfnSaveImageFile(hBoard, szFileName, first, target, start, num);	}

MLONG WINAPI okLoadImageFile(HANDLE hBoard, LPSTR szFileName, MLONG first, TARGET target, MLONG start, MLONG num)
{	return lpfnLoadImageFile(hBoard, szFileName, first, target, start, num);	}

BOOL WINAPI okGetCurrImageInfo(HANDLE hBoard, MLONG lpImgFrmInfo, MLONG lSize)
{	return lpfnGetCurrImageInfo(hBoard, lpImgFrmInfo, lSize);	}


BOOL WINAPI okLoadConfigFile(HANDLE hBoard, LPSTR szFileName)
{	return lpfnLoadConfigFile(hBoard, szFileName);	}

BOOL WINAPI okSaveConfigFile(HANDLE hBoard, LPSTR szFileName)
{	return lpfnSaveConfigFile(hBoard, szFileName);	}

BOOL WINAPI okLoadFlatModelFile(HANDLE hBoard, LPSTR szFileName)
{	return lpfnLoadFlatModelFile(hBoard, szFileName);	}

BOOL WINAPI okSaveFlatModelFile(HANDLE hBoard, LPSTR szFileName)
{	return lpfnSaveFlatModelFile(hBoard, szFileName);	}

 
BOOL WINAPI okOpenSetParamDlg( HANDLE hBoard, HWND hParentWnd)
{	return lpfnOpenSetParamDlg(hBoard, hParentWnd);	}

BOOL WINAPI okOpenSeqCaptureDlg( HANDLE hBoard, HWND hParentWnd)
{	return lpfnOpenSeqCaptureDlg(hBoard, hParentWnd);	}

LPDIBINFO WINAPI okOpenReplayDlg( HANDLE hBoard, HWND hWnd, TARGET src, MLONG total)
{	return lpfnOpenReplayDlg(hBoard, hWnd, src, total);	}

HWND WINAPI okOpenReplayDlgEx( HANDLE hBoard, HWND hWnd, TARGET src, MLONG total, LPBITMAPINFOHEADER lpbi, LPBYTE lpdib)
{	return lpfnOpenReplayDlgEx(hBoard, hWnd, src, total, lpbi, lpdib);	}

INT32	WINAPI okAutoAdjustBright(HANDLE hBoard, LPRECT lpRect, LPVOID dwRes)
{	return lpfnAutoAdjustBright(hBoard, lpRect, dwRes); }

INT32	WINAPI okAutoSetCapRect(HANDLE hBoard, INT32 Width, INT32 Height)
{	return lpfnAutoSetCapRect(hBoard, Width, Height); }

BOOL	WINAPI okOpenSetLUTDlg(HANDLE hBoard, HWND hWnd, LPVOID lpLUT)
{	return lpfnOpenSetLUTDlg(hBoard, hWnd, lpLUT); }

BOOL	WINAPI okUnifyFields(HANDLE hBoard, TARGET target, MLONG start)
{	return lpfnUnifyFields(hBoard, target, start); }

INT32	WINAPI okDiffusionFilter(HANDLE hBoard, TARGET target, MLONG start, SHORT nLoop)
{	return lpfnDiffusionFilter(hBoard, target, start, nLoop);  }

INT32	WINAPI okGuassFilter(HANDLE hBoard, TARGET target, MLONG start)
{	return lpfnGuassFilter(hBoard, target, start);  }

INT32	WINAPI okSharpFilter(HANDLE hBoard, TARGET target, MLONG start, SHORT iClass)
{	return lpfnSharpFilter(hBoard, target, start, iClass);   }

float	WINAPI okGetFocusMeasure(HANDLE hBoard, TARGET target, MLONG start, LPRECT lpRect, SHORT iMethod, SHORT iPreDegree)
{	return lpfnGetFocusMeasure(hBoard, target, start, lpRect, iMethod, iPreDegree);   }

INT32	WINAPI okMultiFrmMean(HANDLE hBoard, TARGET target, MLONG start, MLONG number)
{	return lpfnMultiFrmMean(hBoard, target, start, number);   }

INT32	WINAPI okTakeRectMean(HANDLE hBoard, TARGET target, LPRECT lpRect, MLONG start, short iMode)
{	return lpfnTakeRectMean(hBoard, target, lpRect, start, iMode);   }

INT32	WINAPI okEvaluateHistogram(HANDLE hBoard, TARGET target, LPRECT lpRect, MLONG start, LPDWORD lpHist)
{	return lpfnEvaluateHistogram(hBoard, target, lpRect, start, lpHist);   }

INT32	WINAPI okGetLinExtenMaplut(LPDWORD lpHist, short iNumBits, short iNumChann, short iIntensity, LPWORD lpwLUT)
{	return lpfnGetLinExtenMaplut(lpHist, iNumBits, iNumChann, iIntensity, lpwLUT);   }

INT32	WINAPI okGetHistEquaMaplut(LPDWORD lpHist, short iNumBits, short iNumChann, LPWORD lpwLUT)
{	return lpfnGetHistEquaMaplut(lpHist, iNumBits, iNumChann, lpwLUT);   }

HANDLE WINAPI okBeginEncode(HANDLE hBoard, DWORD dwCodeWay, MLONG lpImageInfo)
{	return lpfnBeginEncode(hBoard, dwCodeWay, lpImageInfo);	}

INT32 WINAPI okEncodeImage(HANDLE hCoder, TARGET src, MLONG start, LPBYTE lpData, MLONG maxlen)
{	return lpfnEncodeImage(hCoder, src, start, lpData, maxlen);	}

INT32 WINAPI okEndEncode(HANDLE hCoder)
{	return lpfnEndEncode(hCoder);	}


HANDLE WINAPI okBeginDecode(HANDLE hBoard, DWORD dwCodeWay, LPBYTE lpData, MLONG lpImageInfo)
{	return lpfnBeginDecode(hBoard, dwCodeWay, lpData, lpImageInfo);	}

INT32 WINAPI okDecodeImage(HANDLE hCoder, LPBYTE lpData, MLONG *length, TARGET target, MLONG start)
{	return lpfnDecodeImage(hCoder, lpData, length, target, start);	}

INT32 WINAPI okEndDecode(HANDLE hCoder)
{	return lpfnEndDecode(hCoder);	}



BOOL	WINAPI okOutputByte(WORD wport, BYTE data)
{	LoadOkApiDll(0);
	return lpfnOutputByte(wport, data);	}

BYTE	WINAPI okInputByte(WORD wport)
{	LoadOkApiDll(0);
	return lpfnInputByte(wport);	}

BOOL	WINAPI okOutputShort(WORD wport, SHORT data)
{	LoadOkApiDll(0);
	return lpfnOutputShort(wport, data);	}

SHORT	WINAPI okInputShort(WORD wport)
{	LoadOkApiDll(0);
	return lpfnInputShort(wport);	}

BOOL	WINAPI okOutputLong(WORD wport, MLONG data)
{	LoadOkApiDll(0);
	return lpfnOutputLong(wport, data);	}

MLONG	WINAPI okInputLong(WORD wport)
{	LoadOkApiDll(0);	
	return lpfnInputLong(wport);	}


BOOL	WINAPI okSetPortBase(WORD wPortBase, SHORT iPortCount)
{	LoadOkApiDll(0);
	return lpfnSetPortBase(wPortBase, iPortCount);	}

SHORT	WINAPI okGetGPIOPort(SHORT index, WORD *wPortBase)
{	LoadOkApiDll(0);
	return lpfnGetGPIOPort(index, wPortBase);	}
		


MWORD	WINAPI okGetAddrForVB(void *lpArry)
{	LoadOkApiDll(0);
	return lpfnGetAddrForVB(lpArry);	}

DWORD	WINAPI okGetTickCount(void)
{	LoadOkApiDll(0);
	return lpfnGetTickCount();	}

void	WINAPI okSleep(DWORD dwMill)
{	LoadOkApiDll(0);
	lpfnSleep(dwMill);	}

DWORD	WINAPI okGetTickCountMicro(LPDWORD lpHiDword)
{	LoadOkApiDll(0);
	return lpfnGetTickCountMicro(lpHiDword);	}

void	WINAPI okSleepMicro(DWORD dwMicro)
{	LoadOkApiDll(0);
	lpfnSleepMicro(dwMicro);	}


//--------audio-----------

HANDLE	WINAPI okOpenAudio(HANDLE hBoard, MLONG lParam)
{	
	LoadOkApiDll(1);
	return lpfnOpenAudio(hBoard, lParam);	
}

BOOL	WINAPI okCloseAudio(HANDLE hAudio)
{	
	BOOL	ret;
	
	ret=lpfnCloseAudio(hAudio);	
	if(ret)
		FreeOkApiDll();

	return ret;
}


MLONG	WINAPI okCaptureAudio(HANDLE hAudio, TARGET target, FARPROC lpfnUserProc, MLONG lParam)
{	return lpfnCaptureAudio(hAudio, target, lpfnUserProc, lParam);	}

BOOL	WINAPI okStopCaptureAudio(HANDLE hAudio)
{	return lpfnStopCaptureAudio(hAudio);	}

INT32	WINAPI okSetAudioParam(HANDLE hAudio, INT32 wParam, INT32 lParam)
{	return lpfnSetAudioParam(hAudio, wParam, lParam);	}

INT32	WINAPI okReadAudioData(HANDLE hAudio, LPBYTE lpAudioBuf, INT32 lReadSize)
{	return lpfnReadAudioData(hAudio, lpAudioBuf, lReadSize);	}




//--------stream-----------

HANDLE	WINAPI okOpenStream(HANDLE hBoard, DWORD lParam)
{	
	LoadOkApiDll(1);
	return lpfnOpenStream(hBoard, lParam);	
}

BOOL	WINAPI okCloseStream(HANDLE hStream)
{	
	BOOL	ret;
	
	ret=lpfnCloseStream(hStream);	
	if(ret)
		FreeOkApiDll();

	return ret;
}


HANDLE	WINAPI okCaptureStream(HANDLE hStream, TARGET target, FARPROC lpfnUserProc, MLONG lMiliSeconds)
{	return lpfnCaptureStream(hStream, target, lpfnUserProc, lMiliSeconds);	}

BOOL	WINAPI okStopCaptureStream(HANDLE hStream, DWORD dwPause)
{	return lpfnStopCaptureStream(hStream, dwPause);	}

MLONG	WINAPI okSetStreamParam(HANDLE hStream, INT32 wParam, MLONG lParam)
{	return lpfnSetStreamParam(hStream, wParam, lParam);	}

INT32	WINAPI okReadStreamData(HANDLE hStream, LPBYTE lpStreamBuf, INT32 lReadSize)
{	return lpfnReadStreamData(hStream, lpStreamBuf, lReadSize);	}

MLONG	WINAPI	okGetCurrStream(HANDLE hStream, LPVOID lParam)
{	return lpfnGetCurrStream(hStream,lParam); }

INT32	WINAPI okSetSerial(HANDLE hBoard, INT32 wParam, INT32 lParam)
{	return lpfnSetSerial( hBoard, wParam, lParam);	}

INT32	WINAPI okReadSerial(HANDLE hBoard, LPVOID lpBuffer, INT32 lSize, MLONG lTimeOut)
{	return lpfnReadSerial( hBoard, lpBuffer, lSize, lTimeOut);	}

BOOL	WINAPI okWriteSerial(HANDLE hBoard, LPVOID lpBuffer, INT32 lSize, MLONG lTimeOut)
{	return lpfnWriteSerial( hBoard, lpBuffer, lSize, lTimeOut);	}




//-----------end-----------------------------------------------------------------------
