#include "qtcallback.h"
#include "ui_qtcallback.h"
#include "qmessagebox.h"
#include "qpixmap.h"
#include "qthread.h"

#pragma execution_character_set("utf-8")
#if defined(Q_OS_LINUX)
    int stricmp(const char * _Str1, const char * _Str2)
    {
        return strcasecmp(_Str1, _Str2);
    }

    int strnicmp(const char * _Str1, const char * _Str, size_t _MaxCount)
    {
        return strncasecmp(_Str1, _Str, _MaxCount);
    }
#endif


extern LPBITMAPINFOHEADER	lpbi;
extern LPBYTE				lpdib;


bool        checkshow=0;
BOOL CALLBACK exBeginCapture(HANDLE hBoard);
BOOL CALLBACK exBackDisplay(HANDLE hBoard, MLONG no);
BOOL CALLBACK exEndCapture(HANDLE hBoard);
long exGetTargetSize(HANDLE hBoard, TARGET tgt, short *width, short *height);
long exSetBitmapHeader(LPBITMAPINFOHEADER lpbi,short width,short height, short bits, short form);

qtcallback::qtcallback(QWidget *parent):
    QMainWindow(parent),
    ui(new Ui::qtcallback)
{
    ui->setupUi(this);
    char string[256];
    checkshow = 1;

    hBoard=exOpenCard();
    if(hBoard == nullptr)
    {
        ui->ratio->setText("open device faild!");
    }
    else {
        okGetTypeCode(hBoard,string);
        ui->ratio->setText(qstr.sprintf("type: %s",string));
    }
    exAllocateDIBMemory(hBoard);
    ui->label->installEventFilter(this);
    ui->label->setStyleSheet("border:1px solid black;");
//      ui->label->setStyleSheet("QLabel{border:2px solid rgb(0, 255, 0);}");
}

qtcallback::~qtcallback()
{
    okCloseBoard(hBoard);
    hBoard = nullptr;

    GlobalFree((HGLOBAL)lpbi);
    lpbi = nullptr;
    GlobalFree((HGLOBAL)lpdib);
    lpdib = nullptr;
    delete ui;
}

HANDLE	qtcallback::exOpenCard()
{
    long	iNoBoards;
    long	error;
    char	str[120];

    //check ok boards sloted in PC
    iNoBoards=okGetImageDevice(nullptr,0);
  //  QMessageBox::about(this,"exOpenCard",QString::number(iNoBoards));

    //check if pre_allocated buffer
    okGetAvailBuffer(nullptr, (MWORD *)&dwBufSize); //whole buffer
    //okGetBufferSize(hBoard,NULL,&dwBufSize); //available buffer for image

    //check if reg device driver for nt/2k/xp
    if( !okSetNTDriver(0) ) { // TRUE:registered already, -1:not nt system
        QMessageBox::about(this, "Warning", "There are not yet registered device service driver!");
    }
    else if( okSetNTDriver(0)==-1 ) { //win95/98
        if( !iNoBoards && (!okSetStaticVxD(0)) )
            QMessageBox::about(this, "Warning", "There are not yet registered vxd device driver!");
    }
    else {
        if(dwBufSize==0) //may be not reg driver, or no board, ...
            QMessageBox::about(this, "Warning", "There are no buffer pre-allocated !");
    }

    //				DialogBox(hInst, szSelectBox, hWnd, (FARPROC)exSelectDlgProc);

    //iCurrUsedNo=1//-1222;
    //open one specified board
    if( !(hBoard=okOpenBoard(&iCurrUsedNo)) ) {//set
        error=okGetLastError();
        if(error==ERR_NOTFOUNDBOARD) {
            sprintf(str," ErrorCode=%d\n\n Not found correct 'Ok series Image Boards' in this Machine! ",error );
         }
        else {
            sprintf(str," ErrorCode=%d\n\n Open selected board failed! ",error);
        }
        QMessageBox::about(this, "Error !", str);

    }
    else {
        error=okGetLastError();
        if (error==ERR_NOTFOUNDVXDDRV) {
            sprintf(str," ErrorCode=%d\n\n Failed to open device driver for Ok Image Board!",error);
            QMessageBox::about(this, "Warning !", str);
        }
    }

    if(!hBoard)
       return nullptr;
    return hBoard;
}

long qtcallback::exAllocateDIBMemory(HANDLE hBoard )
{
    char	flag=0,string[100];
    DWORD	dwDIBMemSize;
    RECT	rcBuf;


    //allocate memory for bi and dib to paint current window
    if(lpbi==nullptr) { //just one time
        lpbi=(LPBITMAPINFOHEADER)GlobalAlloc(GPTR,2048);
    }

    if(!hBoard)
        return 0;

    //get current buffer size
    SetRect(&rcBuf,0,0,-1,-1);
    okSetTargetRect(hBoard,BUFFER,&rcBuf);
    dwDIBMemSize =(((rcBuf.right+3)*4/4)*rcBuf.bottom*4) ; // 32

    if( dwDIBMemSize>dwDIBCurrSize ) {
        dwDIBCurrSize=dwDIBMemSize;
        GlobalFree(lpdib);
        lpdib = nullptr;
    }
    if( lpbi->biSizeImage>dwDIBCurrSize) {
        dwDIBCurrSize=lpbi->biSizeImage;
        if(lpdib)
            GlobalFree(lpdib);
            lpdib = nullptr;
    }


    if(lpdib==nullptr) {
        lpdib=(LPBYTE)GlobalAlloc(GPTR,dwDIBCurrSize);
        flag=1; //changed
    }

    if(!lpdib) { //no allocated
        sprintf(string,"Allocate DIB memory failed !");
        QMessageBox::about(this, "Warning", string);
        return FALSE;
    }


    //GlobalMemoryStatus(&Status);
    if((flag==1) ) //re-allocated
    { //changed or init;
        if( dwDIBCurrSize<= (4*(1<<20)) ) { //for small than 4M
            dwMaxMemSize=dwDIBCurrSize*4;//16M
        }else { //big dib
            dwMaxMemSize=dwDIBCurrSize;//
        }
    }

    return (dwDIBCurrSize); //total allocated
}

void qtcallback::on_start_clicked()
{
    okSetSeqCallback(hBoard,exBeginCapture,exBackDisplay,exEndCapture);
    long ret = okCaptureTo(hBoard,BUFFER,0,-1);//-1: loop infiniately
  //  QMessageBox::about(this,"cap",QString::number(ret));
}

void qtcallback::on_stop_clicked()
{
    okStopCapture(hBoard);
}

bool qtcallback::eventFilter(QObject *obj, QEvent *event)
{
    if (obj == ui->label && QEvent::Paint == event->type()) {
        upPaint();
    }
    return QWidget::eventFilter(obj,event);
}

void qtcallback::upPaint()    //绘图
{
  //  QPainter painter(ui->label);
    //显示图片
 //   QString imagePath = "E:/PhotoTest/drawTest.PNG";   //图片对应路径
 //   painter.drawPixmap(0,0,400,300,QPixmap(imagePath));

    //显示图片的另一种方法：setPixmap,这里不要使用
  //  QImage Image;
  //  Image.load(imagePath);
  //  ui->lb_image->setPixmap(QPixmap::fromImage(Image));
    //封装QImage
       QImage image = QImage((uchar *)lpdib, lpbi->biWidth, lpbi->biHeight, QImage::Format_RGB32); //封装QImage
       ui->label->setPixmap(QPixmap::fromImage(image));
       ui->label->setScaledContents(true);

}


